@@ -1,5 +1,5 @@
 /*
-  Copyright (c) 2016-2018 Montel Laurent <montel@kde.org>
+  Copyright (c) 2016-2020 Laurent Montel <montel@kde.org>
 
   This program is free software; you can redistribute it and/or modify it
   under the terms of the GNU General Public License as published by
@@ -36,10 +36,13 @@ ConfigurePluginDialog::~ConfigurePluginDialog()
     saveConfig();
 }
 
-void ConfigurePluginDialog::initLayout()
+void ConfigurePluginDialog::initLayout(bool addSpacer)
 {
     QVBoxLayout *layout = new QVBoxLayout(this);
     layout->addWidget(createLayout());
+    if (addSpacer) {
+        layout->addStretch(1);
+    }
 
     mButtonBox = new QDialogButtonBox(QDialogButtonBox::Ok | QDialogButtonBox::Cancel | QDialogButtonBox::RestoreDefaults | QDialogButtonBox::Help, this);
     mButtonBox->setObjectName(QStringLiteral("buttonBox"));
