@@ -1,5 +1,5 @@
 /*
-  Copyright (c) 2016-2018 Montel Laurent <montel@kde.org>
+  Copyright (c) 2016-2020 Laurent Montel <montel@kde.org>
 
   This program is free software; you can redistribute it and/or modify it
   under the terms of the GNU General Public License as published by
@@ -24,6 +24,10 @@
 class KActionCollection;
 namespace PimCommon {
 class AbstractGenericPluginInterface;
+/**
+ * @brief The AbstractGenericPlugin class
+ * @author Laurent Montel <montel@kde.org>
+ */
 class PIMCOMMON_EXPORT AbstractGenericPlugin : public QObject
 {
     Q_OBJECT
@@ -31,7 +35,7 @@ public:
     explicit AbstractGenericPlugin(QObject *parent = nullptr);
     ~AbstractGenericPlugin();
 
-    virtual PimCommon::AbstractGenericPluginInterface *createInterface(KActionCollection *ac, QObject *parent = nullptr) = 0;
+    virtual PimCommon::AbstractGenericPluginInterface *createInterface(QObject *parent = nullptr) = 0;
     Q_REQUIRED_RESULT virtual bool hasPopupMenuSupport() const;
     Q_REQUIRED_RESULT virtual bool hasToolBarSupport() const;
     Q_REQUIRED_RESULT virtual bool hasConfigureDialog() const;
@@ -42,6 +46,9 @@ public:
     void setIsEnabled(bool enabled);
     Q_REQUIRED_RESULT bool isEnabled() const;
 
+Q_SIGNALS:
+    void configChanged();
+
 private:
     bool mIsEnabled;
 };
