@@ -1,5 +1,5 @@
 /*
-  Copyright (c) 2016-2019 Montel Laurent <montel@kde.org>
+  Copyright (c) 2016-2020 Laurent Montel <montel@kde.org>
 
   This program is free software; you can redistribute it and/or modify it
   under the terms of the GNU General Public License as published by
@@ -24,7 +24,7 @@
 #include <QString>
 #include <QStringList>
 #include <QPair>
-#include <kpluginmetadata.h>
+#include <KPluginMetaData>
 
 namespace PimCommon {
 /**
