@@ -1,5 +1,5 @@
 /*
-  Copyright (c) 2013-2018 Montel Laurent <montel@kde.org>
+  Copyright (c) 2013-2020 Laurent Montel <montel@kde.org>
 
   This program is free software; you can redistribute it and/or modify it
   under the terms of the GNU General Public License as published by
@@ -17,17 +17,11 @@
 */
 
 #include "checkedcollectionwidget.h"
-#include <RecursiveCollectionFilterProxyModel>
 #include <CollectionFilterProxyModel>
 
 #include <Monitor>
 #include <EntityTreeModel>
-#include <EntityRightsFilterModel>
-#if (QT_VERSION < QT_VERSION_CHECK(5, 10, 0))
-#include <KRecursiveFilterProxyModel>
-#else
 #include <QSortFilterProxyModel>
-#endif
 
 #include <KCheckableProxyModel>
 #include <QLineEdit>
@@ -53,11 +47,7 @@ public:
     QTreeView *mFolderView = nullptr;
     QItemSelectionModel *mSelectionModel = nullptr;
     KCheckableProxyModel *mCheckProxy = nullptr;
-#if (QT_VERSION < QT_VERSION_CHECK(5, 10, 0))
-    KRecursiveFilterProxyModel *mCollectionFilter = nullptr;
-#else
     QSortFilterProxyModel *mCollectionFilter = nullptr;
-#endif
 
     Akonadi::EntityTreeModel *mEntityTreeModel = nullptr;
 };
@@ -67,7 +57,7 @@ CheckedCollectionWidget::CheckedCollectionWidget(const QString &mimetype, QWidge
     , d(new PimCommon::CheckedCollectionWidgetPrivate)
 {
     QVBoxLayout *vbox = new QVBoxLayout(this);
-    vbox->setMargin(0);
+    vbox->setContentsMargins(0, 0, 0, 0);
 
     // Create a new change recorder.
     Akonadi::Monitor *monitor = new Akonadi::Monitor(this);
@@ -92,13 +82,8 @@ CheckedCollectionWidget::CheckedCollectionWidget(const QString &mimetype, QWidge
     d->mCheckProxy = new KCheckableProxyModel(this);
     d->mCheckProxy->setSelectionModel(d->mSelectionModel);
     d->mCheckProxy->setSourceModel(mimeTypeProxy);
-#if (QT_VERSION < QT_VERSION_CHECK(5, 10, 0))
-    d->mCollectionFilter = new KRecursiveFilterProxyModel(this);
-    d->mCollectionFilter->setDynamicSortFilter(true);
-#else
     d->mCollectionFilter = new QSortFilterProxyModel(this);
     d->mCollectionFilter->setRecursiveFilteringEnabled(true);
-#endif
     d->mCollectionFilter->setSourceModel(d->mCheckProxy);
     d->mCollectionFilter->setFilterCaseSensitivity(Qt::CaseInsensitive);
 
