@@ -1,9 +1,10 @@
 /*
-  Copyright (c) 2013-2018 Montel Laurent <montel@kde.org>
+  Copyright (c) 2013-2020 Laurent Montel <montel@kde.org>
 
   This program is free software; you can redistribute it and/or modify it
-  under the terms of the GNU General Public License, version 2, as
-  published by the Free Software Foundation.
+  under the terms of the GNU General Public License as published by
+  the Free Software Foundation; either version 2 of the License, or
+  (at your option) any later version.
 
   This program is distributed in the hope that it will be useful, but
   WITHOUT ANY WARRANTY; without even the implied warranty of
@@ -23,6 +24,10 @@
 
 namespace PimCommon {
 class SelectMultiCollectionDialogPrivate;
+/**
+ * @brief The SelectMultiCollectionDialog class
+ * @author Laurent Montel <montel@kde.org>
+ */
 class PIMCOMMONAKONADI_EXPORT SelectMultiCollectionDialog : public QDialog
 {
     Q_OBJECT
@@ -31,7 +36,7 @@ public:
     explicit SelectMultiCollectionDialog(const QString &mimetype, QWidget *parent = nullptr);
     ~SelectMultiCollectionDialog();
 
-    QVector<Akonadi::Collection> selectedCollection() const;
+    Q_REQUIRED_RESULT QVector<Akonadi::Collection> selectedCollection() const;
 
 private:
     void initialize(const QString &mimetype, const QList<Akonadi::Collection::Id> &selectedCollection = QList<Akonadi::Collection::Id>());
